/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages, SfError } from '@salesforce/core';
import { Flags, loglevel, orgApiVersionFlagWithDeprecations, requiredOrgFlagWithDeprecations, SfCommand, parseVarArgs, } from '@salesforce/sf-plugins-core';
import { ConnectExecutor } from '../../shared/connect/services/ConnectExecutor.js';
import { CommunityCreateResource } from '../../shared/community/connect/CommunityCreateResource.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'create');
/**
 * A command to create a community.
 * This is just an sfdx wrapper around the community create connect endpoint
 */
export class CommunityCreateCommand extends SfCommand {
    static deprecateAliases = true;
    static aliases = ['force:community:create'];
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static strict = false;
    static flags = {
        name: Flags.string({
            char: 'n',
            summary: messages.getMessage('flags.name.summary'),
            required: true,
        }),
        'template-name': Flags.string({
            char: 't',
            summary: messages.getMessage('flags.template-name.summary'),
            description: messages.getMessage('flags.template-name.description'),
            required: true,
            deprecateAliases: true,
            aliases: ['templatename'],
        }),
        'url-path-prefix': Flags.string({
            char: 'p',
            summary: messages.getMessage('flags.url-path-prefix.summary'),
            description: messages.getMessage('flags.url-path-prefix.description'),
            // The api requires you to pass this, it accepts an empty string
            default: '',
            deprecateAliases: true,
            aliases: ['urlpathprefix'],
        }),
        description: Flags.string({
            char: 'd',
            summary: messages.getMessage('flags.description.summary'),
            description: messages.getMessage('flags.description.description'),
        }),
        'target-org': requiredOrgFlagWithDeprecations,
        loglevel,
        'api-version': orgApiVersionFlagWithDeprecations,
    };
    async run() {
        const { flags, argv, args } = await this.parse(CommunityCreateCommand);
        const templateParams = getTemplateParamObjectFromArgs(parseVarArgs(args, argv));
        const createCommand = new CommunityCreateResource({
            name: flags.name,
            urlPathPrefix: flags['url-path-prefix'],
            templateName: flags['template-name'],
            description: flags.description,
            templateParams,
        });
        return new ConnectExecutor(createCommand, flags['target-org'].getConnection(flags['api-version']))
            .callConnectApi()
            .then((results) => {
            this.displayResults(results);
            return results;
        });
    }
    displayResults(results) {
        this.table({
            data: [results],
            columns: ['message', 'name', 'jobId', 'action'],
            title: messages.getMessage('response.styleHeader'),
            overflow: 'wrap',
        });
    }
}
export const getTemplateParamObjectFromArgs = (args) => {
    // make sure there's nothing bad
    const badArgs = Object.keys(args).filter((key) => !key.startsWith('templateParams'));
    if (badArgs.length) {
        throw new SfError(`Invalid argument(s): ${badArgs.join(', ')}`, 'InvalidArgument', [
            'Arguments should start with templateParams, like templateParams.AuthenticationType=UNAUTHENTICATED',
        ]);
    }
    // construct the return object
    const templateParams = Object.fromEntries(Object.entries(args).map(([key, value]) => [key.replace('templateParams.', ''), value]));
    return templateParams;
};
//# sourceMappingURL=create.js.map